module CrmJavaSearch
  module Agents
    class BaseAgent
      attr_reader :organization_id, :entity_class_name, :record_class_name, :record_id

      def initialize(organization_id:, entity_class_name:, record_class_name:, record_id:)
        @organization_id = organization_id
        @entity_class_name = entity_class_name
        @record_class_name = record_class_name
        @record_id = record_id
      end

      def save
        Trans::HttpHandler.post_form(url, id: record_id)

        self
      end

      def destroy
        Trans::HttpHandler.post_form(url, id: record_id, delete: true)

        self
      end

      class << self
        def create(organization_id:, entity_class_name:, record_class_name:, record_id:)
          object = new(
            organization_id: organization_id,
            entity_class_name: entity_class_name,
            record_class_name: record_class_name,
            record_id: record_id
          )
          object.save
        end

        def repeat_search(entity_class_name, organization_id, params)
          repeat_search_url = Trans::Router.repeat_search_url(entity_class_name, organization_id)
          Trans::HttpHandler.post_json(repeat_search_url, params)
        end

        def repeat_check(entity_class_name, organization_id, params)
          repeat_check_url = Trans::Router.repeat_check_url(entity_class_name, organization_id)
          Trans::HttpHandler.post_json(repeat_check_url, params)
        end
      end
    end
  end
end
