module CrmJavaSearch
  module Checkers
    class ApiCheckService

      attr_accessor :user, :organization, :record, :exclude_ids, :id_source, :klass

      def initialize(user: , record: , exclude_ids: [], id_source: nil)
        @user         = user
        @record       = record
        @organization = user.organization
        @exclude_ids = exclude_ids
        @id_source = id_source
        @klass = record.class.name
      end

      def check_duplicate_custom_fields(tail = false, &_proc)
        return unless organization.duplicate_check_enabled?(key: @klass.underscore)

        organization.send("#{@klass.underscore}_duplicate_custom_fields").each do |custom_field|
          raw_field_value = custom_field.raw_field_value_from(record)
          field = organization.send("#{@klass.underscore}_duplicate_field_custom_field_map").invert[custom_field.name]

          next if field.blank? || raw_field_value.blank?

          dup_params = {field: field, field_value: raw_field_value, exclude_ids: exclude_ids, id_source: id_source }.stringify_keys
          checker = "CrmJavaSearch::Checkers::#{@klass}Checker".constantize.new(user: user, entity: record, params: dup_params)
          checker.check

          if ['1', '2'].include?(checker.result[:code])
            message = checker.result[:remark]

            message += "-#{raw_field_value}" if tail

            _proc.call(custom_field) if block_given?

            return raise EntityDuplicateError.new(message)
          end
        end
      end
    end
  end
end
